#!/bin/sh

#1 Check and validate Access Manager credentials
#2 Validate the Access Manager IDP cluster details
#3 Add the Access Manager credentials and cluster details to the AWS SSM parameter store
#4 Install the IDP



source ./install_utility_functions.sh
source ./common_rpms_install.sh

PARSER_DIR=.
SCRIPT_DIR=..
LOG_FILE=/tmp/novell_access_manager/autoscale/idp_ami.log
MAIN_INSTALL_LOG=/tmp/novell_access_manager/autoscale/validate_remote_password.log

ADMIN_NAME=$1
ADMIN_PASS=$2
AC_IP=$3
IDP_CLUSTER_NAME=$4
#MAG_CLUSTER_NAME=$5 - MAG cluster name is not needed for IDP
AWS_KMS_KEY=$5
AWS_S3REGION=$6
AWS_S3BUCKET=$7

EC2_INSTANCE_REGION=$( curl -s http://169.254.169.254/latest/meta-data/placement/availability-zone  )
EC2_INSTANCE_REGION=$( echo "$EC2_INSTANCE_REGION" | sed 's|[a-z]$||g' )

mkdir -p /tmp/novell_access_manager/autoscale
touch $MAIN_INSTALL_LOG
touch $LOG_FILE

> $LOG_FILE


cleanupJava()
{
 echo " cleaning up the setup for fresh install " >> $LOG_FILE
 rpm -e netiq-jrex
 rpm -e novell-base
 rpm -e novell-jdk
 rm -rf /opt/novell/
 rm -rf /opt/netiq/
}

put_secret_value()
{
        local secret_name=$1
        local secret_value=$2

        echo " Writing the value for: $secret_name" >>$LOG_FILE
        #Write the values to EC2 SSM parameter store
        #echo "aws ssm put-parameter --name $secret_name --value $secret_value --type SecureString --key-id $AWS_KMS_KEY --region $EC@_INSTANCE_REGION" >>$LOG_FILE
        aws ssm put-parameter --name $secret_name --value $secret_value --type SecureString --key-id $AWS_KMS_KEY --overwrite --region $EC2_INSTANCE_REGION 1>>$LOG_FILE 2>>$LOG_FILE
}

getIdpClusterID()
{
    response_code=$(curl --write-out %{http_code} --silent --output curl_response -k -X GET "https://$AC_IP:8443/amsvc/v1/idpclusters" -u cn=$ADMIN_NAME,o=novell:$ADMIN_PASS)
    if [[ ("$response_code" == 200) ]]; then
        json_body=$(<curl_response)
        parser_response=$(python -c 'execfile('"\"$PARSER_DIR/json_parser.py"\"'); get_idp_cluster_id()' "$json_body" "$LOG_FILE" "$IDP_CLUSTER_NAME" 2>>$LOG_FILE )
        if [[ ("$parser_response" != "failure") ]]; then
            clusterID=$parser_response
        fi
    fi
    rm -f curl_response
    echo $clusterID
}

copyInstanceLogsToS3()
{
    echo "Backing up application log files to AWS S3 store" >> "$LOG_FILE"
    log_folder=/tmp/novell_access_manager
    instanceIP=`curl http://169.254.169.254/latest/meta-data/local-ipv4`
    tar_bundle=idp_ami_$(date +"%F")_$(date +"%s").tar.gz

    catalina_log=/opt/novell/nam/idp/logs/catalina.out
    jcc_logs=/opt/novell/devman/jcc/logs/jcc-0.log.0
    jcc_configure_logs=jcc_logs=/opt/novell/devman/jcc/logs/configure.log.0

    tar -czvf $tar_bundle $log_folder/* $catalina_log $jcc_logs $jcc_configure_logs

    aws s3 cp $tar_bundle s3://$AWS_S3BUCKET/logs/ --region $AWS_S3REGION

    rm -f $LOG_FILE $MAIN_INSTALL_LOG $tar_bundle
}

cleanupInstance()
{
find /root/.*history /home/*/.*history -exec rm -f {} \;
find / -name "authorized_keys" –exec rm –f {} \;
rm -rf /var/lib/cloud/instances/*
}

if [ ! -f  /opt/novell/java/bin/java ]
then
     install_java
fi


validateRemotePassword "cn=$ADMIN_NAME,o=novell $ADMIN_PASS $AC_IP"

#STATUS=`cat $MAIN_INSTALL_LOG`

if grep --quiet "Success" $MAIN_INSTALL_LOG
then
    cleanupJava

    IDP_CLUSTER_ID=$( getIdpClusterID )
    if [ -z "$IDP_CLUSTER_ID" ]; then
        echo "Cluster not found with given name - $IDP_CLUSTER_NAME" >> $LOG_FILE
        copyInstanceLogsToS3
        exit 3
    fi
    echo "Found the cluster ID with given name, ID - $IDP_CLUSTER_ID" >> $LOG_FILE

    # Writing the NAM Secrets in the AWS SSM
    put_secret_value "AdminUsername" $ADMIN_NAME
    put_secret_value "AdminPassword" $ADMIN_PASS
    put_secret_value "AdminConsolePrivateIP" $AC_IP
    put_secret_value "IDPClusterName" $IDP_CLUSTER_NAME
    put_secret_value "IDPClusterID" $IDP_CLUSTER_ID
    put_secret_value "S3BucketName" $AWS_S3BUCKET
    put_secret_value "S3BucketRegion" $AWS_S3REGION

    #Modify the hostfile
    name=`hostname`
    ip=`curl http://169.254.169.254/latest/meta-data/local-ipv4`
    hostline=`echo $ip $name`
    echo $hostline >> /etc/hosts
    echo "created host entry." >> $LOG_FILE

    echo "Installing the IDP...." >> $LOG_FILE
    #Install the IDP
    cd $SCRIPT_DIR
    if [  -f "/etc/redhat-release" ]
    then
        echo -e "2""\n""y""\n""n""\n""y""\n""${AC_IP}""\n""${ADMIN_NAME}""\n""${ADMIN_PASS}""\n""${ADMIN_PASS}""\n""n""\n" | sh install.sh
    else
        echo -e "2""\n""y""\n""y""\n""${AC_IP}""\n""${ADMIN_NAME}""\n""${ADMIN_PASS}""\n""${ADMIN_PASS}""\n" | sh install.sh
    fi

    #Delete this IDP from the Admin Console
    echo "Deleting the IDP from the Admin Console...." >> $LOG_FILE

    #get the jccid of the server
    jcc_id=`cat /opt/novell/nids/lib/webapp/WEB-INF/jccid.dat`

    echo "curl_commnad: curl -k -X DELETE "https://$AC_IP:8443/amsvc/v1/devices/idp/idp-$jcc_id" -u cn=$ADMIN_NAME.o=novell:***** " >> $LOG_FILE
    curl -k -X DELETE "https://$AC_IP:8443/amsvc/v1/devices/idp/idp-$jcc_id" -u cn=${ADMIN_NAME},o=novell:${ADMIN_PASS} >> $LOG_FILE

    echo "IDP deleted from AC." >> $LOG_FILE
    copyInstanceLogsToS3
    cleanupInstance
    exit 0 ;
else
    echo " Provided credentials are wrong. Please check the AC IP / Admin Name / Admin Password " >> $LOG_FILE
    copyInstanceLogsToS3
    cleanupJava
    exit 1 ;
fi

